Page 49 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 49

Home

    The power of the conspiracy behind the Revolution
    was gaining such force that it would not only sweep
    away King, nobles, and clergy, but eventually, the
    leaders of the Revolution as well. The end result was a

    reign of terror and anarchy.

    Although sentiment in America over the Revolution
    was divided, there were several wise and able statesmen
    who could see the coming holocaust. In his book
    Architects of Conspiracy, William P. Hoar relates the
    insight of John Adams:

    skeptical of the French Revolution from its beginning.
    Among these was the always perceptive John Adams.
    Biographer Page Smith reports that Adams "from the
    first moment viewed it with misgivings .... At the same time
    he could not forbear to point out 'that the form of
    government they have adopted' could be ‘nothing more
    than a transient experiment. An obstinate adherence to it'
    would involve France ‘in great and lasting calamities.’ A
    single assembly would be dominated by demagogues and
    the result would be repeated upheavals and disorder —
    a succession of bloody contentions."”

    Gouverneur Morris, the conservative statesman who had
    been the architect of much of the U. S. Constitution.

    44

    The Secret Side of History

    But the fact is that a number of Americans were

    Another American statesman who viewed events in

    France with alarm was Gouverneur Morris. William P.

    Hoar also recorded Morris' views:

    On the scene as our Minister in Paris was